@@ -8,11 +8,17 @@ import math
 from domonic.javascript import Math
 
 
-class vec4():
-    """[vec4]
-    """
+class vec4:
+    """[vec4]"""
 
-    def __init__(self, x: float = 0.0, y: float = 0.0, z: float = 0.0, w: float = 0.0, n: float = 1.0):
+    def __init__(
+        self,
+        x: float = 0.0,
+        y: float = 0.0,
+        z: float = 0.0,
+        w: float = 0.0,
+        n: float = 1.0,
+    ):
         self.x: float = x
         self.y: float = y
         self.z: float = z
